@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2011 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -110,7 +110,7 @@ public final class NewCallAction extends AbstractVoipNowHTTPAction<GetMethod> {
                     try {
                         jsonArray = (JSONArray) data;
                     } catch (final ClassCastException e) {
-                        final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(NewCallAction.class);
+                        final org.apache.commons.logging.Log log = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(NewCallAction.class));
                         log.warn(e.getMessage(), e);
                         try {
                             jsonArray = new JSONArray(data.toString());
@@ -161,6 +161,7 @@ public final class NewCallAction extends AbstractVoipNowHTTPAction<GetMethod> {
             try {
                 return parseXML(getMethod);
             } finally {
+                closeResponse(getMethod);
                 getMethod.releaseConnection();
             }
         } catch (final UnsupportedEncodingException e) {
@@ -198,7 +199,7 @@ public final class NewCallAction extends AbstractVoipNowHTTPAction<GetMethod> {
         int voipnowResponseCode = 0;
         if (matcher.find()) {
             voipnowResponseCode = ActionUtility.getUnsignedInteger(matcher.group(1));
-            if (voipnowResponseCode > 0) {
+            if (voipnowResponseCode != 0 && (voipnowResponseCode < 200 || voipnowResponseCode >= 400)) {
                 final Matcher codeMatcher = PATTERN_CODE.matcher(responseBody);
                 if (codeMatcher.find()) {
                     final Matcher m2 = PATTERN_TEXT.matcher(responseBody);
@@ -215,7 +216,7 @@ public final class NewCallAction extends AbstractVoipNowHTTPAction<GetMethod> {
 
     @Override
     protected String getPath() {
-        return "/callapi/204/Calls/MakeCall/";
+        return "/callapi/204/Calls/MakeCall";
     }
 
     @Override
